clear all

% Define the grid:
h = 0.01;
t = 0:h:1;

% Define the alphas to be used:
alpha_vec = [0.01 0.1 0.5 1 2 3 4 5];

% Prepare residuals:
res = zeros(4,length(alpha_vec));

% Loop over the alphas:
for a = 1:length(alpha_vec)
    % Evaluate the function:
    alpha = alpha_vec(a);
    b = exp(-alpha*t)';
    % Prepare plots:
    if (alpha == 0.01)||(alpha == 5)
        figure()
        hold all
        plot(t,b)
        title(sprintf('Data fit for alpha = %f',alpha))
        xlabel('t')
    end
    % Loop over the degrees:
    for n = 1:4
        % Get the matrix:
        A = PolynomialLeastSquares(t,n);
        % Determine the coefficients:
        x = (A'*A)\(A'*b);
        % Compute the residual:
        res(n,a) = norm(A*x - b);
        if (alpha == 0.01)||(alpha == 5)
            plot(t,A*x)
        end
    end
    if (alpha == 0.01)||(alpha == 5)
        legend('True data','n = 1','n = 2','n = 3','n = 4')
    end
end

figure()
hold all
for n = 1:4
    plot(alpha_vec,res(n,:))
end
title('Residual of least squares fit')
xlabel('alpha')
ylabel('r')
legend('n = 1','n = 2','n = 3','n = 4')